inflight_request_manager library
Classes
-
InFlightRequestManager<
T> -
Manages in-flight requests to prevent duplicate operations identified by unique IDs.
If a request with the same ID is already in progress, it can either return the existing
result or override it with a new request based on the
overrideflag.